@@ -1,5 +1,6 @@
 import contextlib
 import copy
+import sys
 import warnings
 
 import numpy as np
@@ -224,12 +225,12 @@ class Coordinates(object):
             name = ''
         self.name = name
         self.parent = None
-        self._hook = hook if hook else lambda: None
+        self._hook = hook
 
     @contextlib.contextmanager
     def disable_hook(self):
         hook = self._hook
-        self._hook = lambda: None
+        self._hook = None
         try:
             yield
         finally:
@@ -269,7 +270,8 @@ class Coordinates(object):
                [ 0.00000000e+00,  1.00000000e+00,  0.00000000e+00],
                [-1.00000000e+00,  0.00000000e+00,  2.22044605e-16]])
         """
-        self._hook()
+        if self._hook is not None:
+            self._hook()
         return self._rotation
 
     @rotation.setter
@@ -325,7 +327,8 @@ class Coordinates(object):
         >>> c.translation
         array([0.1, 0.2, 0.3])
         """
-        self._hook()
+        if self._hook is not None:
+            self._hook()
         return self._translation
 
     @translation.setter
@@ -1049,7 +1052,8 @@ class Coordinates(object):
 
     def worldcoords(self):
         """Return thisself"""
-        self._hook()
+        if self._hook is not None:
+            self._hook()
         return self
 
     def copy_worldcoords(self):
@@ -1513,6 +1517,39 @@ class CascadedCoords(Coordinates):
                              'get type=={}'.format(type(c)))
         self._parent = c
 
+    def __getstate__(self):
+        assert self._worldcoords._hook == self.update
+        d = self.__dict__.copy()
+
+        is_python3 = sys.version_info.major > 2
+        if is_python3:
+            # NOTE: the following deepcopy is costly. For example,
+            # copying raw CascadedCoords with the following procedure
+            # makes pickling 2x slower. Thus, we don't do that if python3.
+            return d
+        else:
+            # NOTE: setting self._worldcoords._hook = None before deepcopy
+            # is important. Without this, infinite recursion will occur
+            # because self._worldcoords._hook is otherwise a method
+            # of CascadedCoords.
+            self._worldcoords._hook = None
+            d["_worldcoords"] = copy.deepcopy(self._worldcoords)
+            d["_worldcoords"].__setattr__("_hook", None)
+
+            # recover the original _hook
+            self._worldcoords._hook = self.update
+            return d
+
+    def __setstate__(self, d):
+        self.__dict__ = d
+        is_python3 = sys.version_info.major > 2
+        if is_python3:
+            return
+        else:
+            assert self._worldcoords._hook is None  # as we set in __getstate__
+            self._worldcoords._hook = self.update  # register again
+            assert self._worldcoords._hook == self.update
+
 
 def coordinates_p(x):
     """Return whether an object is an instance of a class or of a subclass"""
