@@ -1531,7 +1531,7 @@ def angle_between_vectors(v1, v2, normalize=True,
     return np.arccos(np.clip(dot if directed else np.fabs(dot), -1.0, 1.0))
 
 
-def counter_clockwise_angle_between_vectors(v1, v2, normal_vector):
+def counter_clockwise_angle_between_vectors(v1, v2, normal_vector=None):
     """Returns the counter clockwise angle in radians between two vectors.
 
     Parameters
@@ -1540,7 +1540,7 @@ def counter_clockwise_angle_between_vectors(v1, v2, normal_vector):
         input vector.
     v2 : numpy.ndarray, list[float] or tuple(float)
         input vector.
-    normal_vector : numpy.ndarray, list[float] or tuple(float)
+    normal_vector : numpy.ndarray, list[float] or tuple(float) or None
         Base plane's normal vector.
 
     Returns
@@ -1549,6 +1549,8 @@ def counter_clockwise_angle_between_vectors(v1, v2, normal_vector):
         counter clockwise angle between v1 and v2.
         Return values in [0 radian, 2 * np.pi radian].
     """
+    if normal_vector is None:
+        normal_vector = normal_vector(np.cross(v1, v2))
     # https://stackoverflow.com/questions/14066933/direct-way-of-computing-clockwise-angle-between-2-vectors  # NOQA
     det = triple_product(normal_vector, v1, v2)
     dot = np.dot(v1, v2)
@@ -1558,7 +1560,7 @@ def counter_clockwise_angle_between_vectors(v1, v2, normal_vector):
     return angle
 
 
-def clockwise_angle_between_vectors(v1, v2, normal_vector):
+def clockwise_angle_between_vectors(v1, v2, normal_vector=None):
     """Returns the clockwise angle in radians between two vectors.
 
     Parameters
@@ -1567,7 +1569,7 @@ def clockwise_angle_between_vectors(v1, v2, normal_vector):
         input vector.
     v2 : numpy.ndarray, list[float] or tuple(float)
         input vector.
-    normal_vector : numpy.ndarray, list[float] or tuple(float)
+    normal_vector : numpy.ndarray, list[float] or tuple(float) or None
         Base plane's normal vector.
 
     Returns
@@ -1576,6 +1578,8 @@ def clockwise_angle_between_vectors(v1, v2, normal_vector):
         clockwise angle between v1 and v2.
         Return values in [0 radian, 2 * np.pi radian].
     """
+    if normal_vector is None:
+        normal_vector = normal_vector(np.cross(v1, v2))
     normal_vector = - np.array(normal_vector)
     det = triple_product(normal_vector, v1, v2)
     dot = np.dot(v1, v2)
